from django.core.exceptions import ValidationError
from django import forms
from django.shortcuts import render
from django.http import HttpResponse, HttpResponseBadRequest, HttpResponseNotAllowed, HttpResponseNotFound
from django.shortcuts import redirect
from django.contrib.auth.decorators import login_required
from warpauth.ldap_connector import LDAPConnector
from warpauth.models import LdapUser, LdapUserForm
from warpauth.util import *
import logging

##
# http://www.python-ldap.org/doc/html/ldap.html#ldap.LDAPObject
# ToDo: first- and lastname, email, public?
##

@login_required(login_url='/login/', redirect_field_name=None)
def index(request):
    pages["error"] = ""
    pages["success"] = False
    pages['ldap_groups'] = request.user.ldap_user.group_names
    pages['ldap_user_form'] = LdapUserForm(instance=LdapUser.objects.get(uid=str(request.user)))
    return HttpResponse(render(request, 'warpauth/profile.html', pages))


@login_required(login_url='/login/', redirect_field_name=None)
def change_information(request):
    pages["error"] = ""
    if request.method != 'POST':
        return redirect("/profile")

    user = LdapUser.objects.get(uid=str(request.user))
    first_name = request.POST["first_name"]
    last_name = request.POST["last_name"]
    email = request.POST["email"]

    f = forms.EmailField()
    try:
        f.clean(email)
    except ValidationError as e:
        pages["error"] = "Invalid Email"
        return redirect("/profile")
    cn = first_name + " " + last_name
    cn = cn.strip()
    if first_name == "":
        first_name = "None"
    if last_name == "":
        last_name = "None"
    if cn == "":
        cn = "None"
    user.first_name = first_name
    user.last_name = last_name
    user.cn = cn
    user.email = email
    user.save()

    return redirect("/profile")


@login_required(login_url='/login/', redirect_field_name=None)
def change_password(request):
    pages["error"] = ""
    pages["success"] = False

    if request.method != 'POST':
        return redirect("/")

    if "old_pw" not in request.POST or "new_pw" not in request.POST or "new_pw_confirm" not in request.POST:
        pages["error"] = "Please fill in all fields"
    elif request.POST["new_pw"] != request.POST["new_pw_confirm"]:
        pages["error"] = "Password confirmation did not match"
    else:
        ldap_connector = LDAPConnector()
        ret = ldap_connector.change_password(request.user.ldap_user.dn, request.POST["old_pw"], request.POST["new_pw"])
        if ret == -1:
            pages["error"] = "Old password did not match"
        else:
            pages["success"] = True
    return HttpResponse(render(request, 'warpauth/profile.html', pages))
